@@ -5,6 +5,7 @@ This checks that autoflake never introduces incorrect syntax. This is
 done by doing a syntax check after the autoflake run. The number of
 Pyflakes warnings is also confirmed to always improve.
 """
+
 from __future__ import annotations
 
 import argparse
@@ -12,11 +13,10 @@ import os
 import shlex
 import subprocess
 import sys
-from typing import Sequence
+from collections.abc import Sequence
 
 import autoflake
 
-
 ROOT_PATH = os.path.abspath(os.path.dirname(__file__))
 AUTOFLAKE_BIN = "'{}' '{}'".format(
     sys.executable,
@@ -161,7 +161,7 @@ def process_args() -> argparse.Namespace:
     parser.add_argument(
         "--expand-star-imports",
         action="store_true",
-        help="expand wildcard star imports with undefined " "names",
+        help="expand wildcard star imports with undefined names",
     )
 
     parser.add_argument(
@@ -172,19 +172,19 @@ def process_args() -> argparse.Namespace:
     parser.add_argument(
         "--remove-all-unused-imports",
         action="store_true",
-        help='pass "--remove-all-unused-imports" option to ' "autoflake",
+        help='pass "--remove-all-unused-imports" option to autoflake',
     )
 
     parser.add_argument(
         "--remove-duplicate-keys",
         action="store_true",
-        help='pass "--remove-duplicate-keys" option to ' "autoflake",
+        help='pass "--remove-duplicate-keys" option to autoflake',
     )
 
     parser.add_argument(
         "--remove-unused-variables",
         action="store_true",
-        help='pass "--remove-unused-variables" option to ' "autoflake",
+        help='pass "--remove-unused-variables" option to autoflake',
     )
 
     parser.add_argument(
